@@ -1,19 +1,14 @@
 /***************************************************************************
-                          optionen.h  -  description                              
-                             -------------------                                         
-    begin                : Sat Feb 19 21:09:25 MET 2000 
-                                           
-    copyright            : (C) 1999 by Daniel Reith                         
-    email                : DanR@gmx.de
-	
- ***************************************************************************/
-
-/***************************************************************************
+ *   copyright            : (C) 1999 by Daniel Reith                       *
+ *   email                : DanR@gmx.de                                    *
+ *                                                                         *
+ *   copyright           : (C) 2003 by Hendrik Sattler                     *
+ *   mail                : pingos@hendrik-sattler.de                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
@@ -22,27 +17,22 @@
 
 #include "wx/wx.h"
 
-class ODialog: public wxDialog
-{
-  DECLARE_EVENT_TABLE()
- private:
-   wxComboBox* sprache;
-   wxComboBox* tastatur;
-   wxStaticText* st;
-   wxStaticText* tt;
-   wxButton *ok;
-   wxButton *ab;
+class ODialog: public wxDialog {
  public:
   ODialog(wxWindow* parent);
-
-  void OnOK(wxCommandEvent* event);
-  void OnCancel(wxCommandEvent* event);
+  ~ODialog();
   
-};
-
-enum
-{
-  GEAENDERT = 493
+  void OnOK(wxCommandEvent* event);
+  
+ private:
+  wxStaticText descr1;
+  wxComboBox* selection1;
+  wxStaticText descr2;
+  wxComboBox* selection2;
+  wxButton btnSave;
+  wxButton btnCancel;
+  
+  DECLARE_EVENT_TABLE()
 };
 
 #endif
